@@ -33,9 +33,10 @@
 #  define MAILIMPORTER_DEPRECATED_NO_EXPORT MAILIMPORTER_NO_EXPORT MAILIMPORTER_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define MAILIMPORTER_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef MAILIMPORTER_NO_DEPRECATED
+#    define MAILIMPORTER_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
